@@ -2,6 +2,7 @@ package Test::Able::Role::Meta::Class;
 
 use Moose::Role;
 use Moose::Util::TypeConstraints;
+use Scalar::Util;
 use Test::Able::Role::Meta::Method;
 use Test::Able::Method::Array;
 
@@ -11,13 +12,20 @@ with qw( Test::Able::Planner );
 
 Test::Able::Role::Meta::Class - Main metarole
 
+=head1 DESCRIPTION
+
+This metarole gets applied to the Moose::Meta::Class metaclass objects
+for all Test::Able objects.  This metarole also pulls in
+L<Test::Able::Planner>.
+
 =head1 ATTRIBUTES
 
 =over
 
 =item method_types
 
-Default is startup, setup, test, teardown, and shutdown.
+The names of the different types of test-related methods.
+The default set is startup, setup, test, teardown, and shutdown.
 
 =cut
 
@@ -27,13 +35,28 @@ has 'method_types' => (
 
 =item *_methods
 
-Accessors for the method types.
+The test-related method lists.  There will be one for each method
+type.  The default set will be:
+
+startup_methods
+setup_methods
+test_methods
+teardown_methods
+shutdown_methods
+
+These lists are what forms the basis of the test execution plan.
+
+The lists themselves will be coerced into L<Test::Able::Method::Array> objects
+just for the convenience of overloading for hash access.  The elements of the
+lists will be L<Test::Able::Role::Meta::Method>-based method metaclass
+objects.
 
 =cut
 
 for ( @{ __PACKAGE__->_build_method_types } ) {
     has "${_}_methods" => (
-        is => 'rw', isa => 'MethodArray', lazy_build => 1, coerce => 1,
+        is => 'rw', isa => 'Test::Able::MethodArray', lazy_build => 1,
+        coerce => 1,
         trigger => sub {
             my ( $self, $value, ) = @_;
 
@@ -44,16 +67,19 @@ for ( @{ __PACKAGE__->_build_method_types } ) {
     );
 }
 
-subtype 'MethodArray'
+subtype 'Test::Able::MethodArray'
   => as 'Object'
   => where { $_->isa( 'Test::Able::Method::Array' ); };
 
-coerce 'MethodArray'
+coerce 'Test::Able::MethodArray'
   => from 'ArrayRef'
   => via { bless( $_, 'Test::Able::Method::Array' ); };
 
 =item test_objects
 
+The list of L<Test::Able::Object>-based objects that the test runner
+object will iterate through to make up the test run.
+
 =cut
 
 has 'test_objects' => (
@@ -62,6 +88,8 @@ has 'test_objects' => (
 
 =item current_test_object
 
+The test object that is currently being executed (or introspected).
+
 =cut
 
 has 'current_test_object' => (
@@ -70,6 +98,11 @@ has 'current_test_object' => (
 
 =item current_test_method
 
+The method metaclass object of the associated test method.
+This is only useful from within a setup or teardown method.
+Its also available in the test method itself but current_method()
+would be exactly the same in a test method and its shorter to type.
+
 =cut
 
 has 'current_test_method' => (
@@ -78,6 +111,9 @@ has 'current_test_method' => (
 
 =item current_method
 
+The method metaclass object of the currently executing test-related
+method.
+
 =cut
 
 has 'current_method' => (
@@ -86,6 +122,9 @@ has 'current_method' => (
 
 =item test_runner_object
 
+The test object that will be running the show.  It may itself be in the
+test_objects list.  The run_tests() method sets this value to its invocant.
+
 =cut
 
 has 'test_runner_object' => (
@@ -94,6 +133,11 @@ has 'test_runner_object' => (
 
 =item dry_run
 
+Setting this true will cause all test-related method execution to be skipped.
+This means things like method exception handling, method plan handling, and
+Test::Builder integration will also not happen.  One use of this could be to
+print out the execution plan.  The default is 0.
+
 =cut
 
 has 'dry_run' => (
@@ -102,15 +146,76 @@ has 'dry_run' => (
 
 =item on_method_plan_fail
 
+Determines what is done, if anything, when the observed method plan doesn't
+match the expected method plan after the test-related method runs.  If this
+attribute is not set then nothing special is done.  Setting this to log or die
+will cause the failure to be logged via log() or just died upon.  The default
+is log.
+
+=cut
+
+enum 'Test::Able::MethodPlanFailAction' => qw( die log );
+
+has 'on_method_plan_fail' => (
+    is => 'rw', isa => 'Test::Able::MethodPlanFailAction', default => 'log',
+    clearer => 'clear_on_method_plan_fail',
+);
+
+=item on_method_exception
+
+Determines what is done, if anything, when an exception is thrown within a
+test-related method.
+
+If this attribute isn't set then the exception is simply rethrown.  This is
+the default.
+
+If its set to "continue" then the exception will be silently ignored.
+
+And if set to "continue_at_level" the exception will also be silently ignored
+and the test runner will skip over lower levels, if there are any, of the test
+execution plan.  The levels are defined as follows. The startup and shutdown
+methods are at the first level.  The setup and teardown methods are the second
+level.  And test methods are the third and last level.  Or in visual form:
+
+startup
+    setup
+        test
+    teardown
+shutdown
+
+In addition, when this attribute is set to continue or continue_at_level the
+exceptions will be recorded in the method_exceptions attribute of the
+currently executing test object.
+
+There is only one way to cause a fatal exception when this attribute is set to
+continue or continue_at_level.  And that is to throw a
+L<Test::Able::FatalException> exception.
+
+=cut
+
+enum 'Test::Able::MethodExceptionAction' => qw( continue continue_at_level );
+
+has 'on_method_exception' => (
+    is => 'rw', isa => 'Test::Able::MethodExceptionAction',
+    clearer => 'clear_on_method_exception',
+);
+
+=item method_exceptions
+
+List of exceptions that have occurred while inside a test-related method in
+this test object.  Each element of the list is a hashref that looks like this:
+
+ {
+     method    => $self->current_method,
+     exception => $exception,
+ }
+
 =back
 
 =cut
 
-enum MethodPlanFailAction => qw( die log );
-
-has 'on_method_plan_fail' => (
-    is => 'rw', isa => 'MethodPlanFailAction', default => 'log',
-    clearer => 'clear_on_method_plan_fail',
+has 'method_exceptions' => (
+    is => 'rw', isa => 'ArrayRef[HashRef]', lazy_build => 1,
 );
 
 sub _build_method_types {
@@ -156,14 +261,21 @@ sub _build_test_objects {
       ? [ $self->current_test_object, ] : [];
 }
 
+sub _build_method_exceptions { []; }
+
 =head1 METHODS
 
 =over
 
 =item run_tests
 
-=cut
+The main test runner method.  Iterates over test_objects list calling
+run_methods() to run through the test execution plan.
 
+Manages test_runner_object, current_test_object, runner_plan, and
+last_runner_plan along the way.
+
+=cut
 sub run_tests {
     my ( $self, ) = @_;
 
@@ -180,8 +292,10 @@ sub run_tests {
     for ( @{ $self->test_objects } ) {
         $_->meta->current_test_object( $_ );
 
+        my $exceptions_before_startup = @{ $self->method_exceptions };
         $_->meta->run_methods( 'startup'  );
-        $_->meta->run_methods( 'test'     );
+        $_->meta->run_methods( 'test'     )
+          if $exceptions_before_startup == @{ $self->method_exceptions };
         $_->meta->run_methods( 'shutdown' );
 
         $_->meta->clear_current_test_object;
@@ -197,6 +311,11 @@ sub run_tests {
 
 =item run_methods
 
+Executes a test-related method list as part of the test execution plan.  Takes
+one argument and that's the name of the test-related method type.  Also, for
+each test method, it calls run_methods() for the setup and teardown method
+lists.
+
 =cut
 
 sub run_methods {
@@ -207,24 +326,47 @@ sub run_methods {
     my $count         = @{ $methods };
     my $i;
     for ( @{ $methods } ) {
+        my $setup_exception_count;
         if ( $type eq 'test' ) {
             $self->current_test_method( $_ );
+            my $exceptions_before_setup = @{ $self->method_exceptions };
             $self->run_methods( 'setup' ) if $_->do_setup;
+            $setup_exception_count
+              = @{ $self->method_exceptions } - $exceptions_before_setup;
         }
-        $self->current_method( $_ );
 
         my $method_name = $_->name;
-        $self->log(
-            $self->current_test_object . '->' . $method_name
-              . "($type/" . $_->plan . ")"
-              . '('. ++$i . "/$count)"
-        );
-        unless ( $self->dry_run ) {
+        unless ( $setup_exception_count ) {
+            $self->current_method( $_ );
+            $self->log(
+                $self->current_test_object . '->' . $method_name
+                . "($type/" . $_->plan . ")"
+                . '('. ++$i . "/$count)"
+            );
+        }
+
+        unless ( $setup_exception_count || $self->dry_run ) {
             my $tests_before = $self->builder->{Curr_Test};
-            $self->current_test_object->$method_name;
-            my $tests_diff = $self->builder->{Curr_Test} - $tests_before;
+
+            eval { $self->current_test_object->$method_name; };
+            if ( my $exception = $@ ) {
+                die $exception unless $self->on_method_exception;
+
+                my $test_object_meta = $self->current_test_object->meta;
+                push(
+                    @{ $test_object_meta->method_exceptions },
+                    {
+                        method    => $self->current_method,
+                        exception => $exception,
+                    }
+                );
+
+                die $exception if Scalar::Util::blessed( $exception )
+                  && $exception->isa( 'Test::Able::FatalException' );
+            }
 
             if ( $self->on_method_plan_fail && $_->plan =~ /^\d+$/ ) {
+                my $tests_diff = $self->builder->{Curr_Test} - $tests_before;
                 if ( $tests_diff != $_->plan ) {
                     my $msg = "Method $method_name planned " . $_->plan
                       . " tests but ran $tests_diff.";
@@ -248,6 +390,11 @@ sub run_methods {
 
 =item build_methods
 
+Builds a test-related method list from the method metaclass objects associated
+with this metaclass object.  The method list is sorted alphabetically by
+method name.  Takes one argument and that's the name of the test-related
+method type.
+
 =cut
 
 sub build_methods {
@@ -270,6 +417,8 @@ sub build_methods {
 
 =item build_all_methods
 
+Convenience method to call build_methods() for all method types.
+
 =cut
 
 sub build_all_methods {
@@ -286,6 +435,8 @@ sub build_all_methods {
 
 =item clear_all_methods
 
+Convenience method to clear all the test-related method lists out.
+
 =cut
 
 sub clear_all_methods {
@@ -302,6 +453,9 @@ sub clear_all_methods {
 
 =item log
 
+All logging goes through this method.  It sends its args along to
+Test::Builder::diag.  And only if $ENV{TEST_VERBOSE} is set.
+
 =cut
 
 sub log {
@@ -347,7 +501,8 @@ sub _build_plan {
 
 =item clear_plan
 
-Special purpose plan clearer that dumps plan and runner_plan.
+Special purpose plan clearer that dumps the test object's plan and the test
+runner's plan in one shot.
 
 =back
 
@@ -389,6 +544,8 @@ sub _build_runner_plan {
 
     return $plan if $self->dry_run;
 
+    $self->builder->no_plan unless $self->builder->has_plan;
+
     # Update Test::Builder.
     if ( $self->builder->{No_Plan} || $self->builder->{was_No_Plan} ) {
         if ( $plan =~ /^\d+$/ ) {
@@ -432,24 +589,6 @@ sub _hack_test_builder {
     };
 }
 
-=head1 SEE ALSO
-
-=over
-
-=item support
-
- #moose on irc.perl.org
-
-=item code
-
- http://github.com/jdv/test-able/tree/master
-
-=item L<Test::Class>
-
-=item L<Test::Builder>
-
-=back
-
 =head1 AUTHOR
 
 Justin DeVuyst, C<justin@devuyst.com>
